summaryrefslogtreecommitdiff
path: root/libraries/ghci/GHCi/TH.hs
diff options
context:
space:
mode:
Diffstat (limited to 'libraries/ghci/GHCi/TH.hs')
-rw-r--r--libraries/ghci/GHCi/TH.hs9
1 files changed, 4 insertions, 5 deletions
diff --git a/libraries/ghci/GHCi/TH.hs b/libraries/ghci/GHCi/TH.hs
index 5351b90ef1..15d70ceb4f 100644
--- a/libraries/ghci/GHCi/TH.hs
+++ b/libraries/ghci/GHCi/TH.hs
@@ -19,7 +19,7 @@ Here is an overview of how TH works with -fexternal-interpreter.
Initialisation
~~~~~~~~~~~~~~
-GHC sends a StartTH message to the server (see TcSplice.getTHState):
+GHC sends a StartTH message to the server (see GHC.Tc.Gen.Splice.getTHState):
StartTH :: Message (RemoteRef (IORef QState))
@@ -79,7 +79,7 @@ For each splice
After typechecking
~~~~~~~~~~~~~~~~~~
-GHC sends a FinishTH message to the server (see TcSplice.finishTH).
+GHC sends a FinishTH message to the server (see GHC.Tc.Gen.Splice.finishTH).
The server runs any finalizers that were added by addModuleFinalizer.
@@ -87,8 +87,7 @@ Other Notes on TH / Remote GHCi
* Note [Remote GHCi] in compiler/ghci/GHCi.hs
* Note [External GHCi pointers] in compiler/ghci/GHCi.hs
- * Note [TH recover with -fexternal-interpreter] in
- compiler/typecheck/TcSplice.hs
+ * Note [TH recover with -fexternal-interpreter] in GHC.Tc.Gen.Splice
-}
import Prelude -- See note [Why do we import Prelude here?]
@@ -168,7 +167,7 @@ instance TH.Quasi GHCiQ where
qNewName str = ghcCmd (NewName str)
qReport isError msg = ghcCmd (Report isError msg)
- -- See Note [TH recover with -fexternal-interpreter] in TcSplice
+ -- See Note [TH recover with -fexternal-interpreter] in GHC.Tc.Gen.Splice
qRecover (GHCiQ h) a = GHCiQ $ \s -> mask $ \unmask -> do
remoteTHCall (qsPipe s) StartRecover
e <- try $ unmask $ runGHCiQ (a <* ghcCmd FailIfErrs) s